@@ -7,9 +7,9 @@ import vtk.*;
 public class vtkAlgorithm extends vtkObject
 {
 
-  private native String GetClassName_0();
-  public String GetClassName()
-    { return GetClassName_0(); }
+  private native int IsTypeOf_0(String id0);
+  public int IsTypeOf(String id0)
+    { return IsTypeOf_0(id0); }
 
   private native int IsA_1(String id0);
   public int IsA(String id0)
@@ -25,7 +25,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkExecutive)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetExecutive_4(vtkExecutive id0);
   public void SetExecutive(vtkExecutive id0)
@@ -45,7 +45,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetOutputPortInformation_8(int id0);
   public vtkInformation GetOutputPortInformation(int id0) {
@@ -53,7 +53,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetInformation_9();
   public vtkInformation GetInformation() {
@@ -61,7 +61,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetInformation_10(vtkInformation id0);
   public void SetInformation(vtkInformation id0)
@@ -137,7 +137,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long INPUT_IS_REPEATABLE_28();
   public vtkInformationIntegerKey INPUT_IS_REPEATABLE() {
@@ -145,7 +145,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long INPUT_REQUIRED_FIELDS_29();
   public vtkInformationInformationVectorKey INPUT_REQUIRED_FIELDS() {
@@ -153,7 +153,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformationInformationVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long INPUT_REQUIRED_DATA_TYPE_30();
   public vtkInformationStringVectorKey INPUT_REQUIRED_DATA_TYPE() {
@@ -161,7 +161,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformationStringVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long INPUT_ARRAYS_TO_PROCESS_31();
   public vtkInformationInformationVectorKey INPUT_ARRAYS_TO_PROCESS() {
@@ -169,7 +169,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformationInformationVectorKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long INPUT_PORT_32();
   public vtkInformationIntegerKey INPUT_PORT() {
@@ -177,7 +177,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long INPUT_CONNECTION_33();
   public vtkInformationIntegerKey INPUT_CONNECTION() {
@@ -185,7 +185,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long CAN_PRODUCE_SUB_EXTENT_34();
   public vtkInformationIntegerKey CAN_PRODUCE_SUB_EXTENT() {
@@ -193,7 +193,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long CAN_HANDLE_PIECE_REQUEST_35();
   public vtkInformationIntegerKey CAN_HANDLE_PIECE_REQUEST() {
@@ -201,7 +201,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetInputArrayToProcess_36(int id0,int id1,int id2,int id3,String id4);
   public void SetInputArrayToProcess(int id0,int id1,int id2,int id3,String id4)
@@ -225,7 +225,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void RemoveAllInputs_41();
   public void RemoveAllInputs()
@@ -237,7 +237,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetInputDataObject_43(int id0,int id1);
   public vtkDataObject GetInputDataObject(int id0,int id1) {
@@ -245,7 +245,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void SetInputConnection_44(int id0,vtkAlgorithmOutput id1);
   public void SetInputConnection(int id0,vtkAlgorithmOutput id1)
@@ -297,7 +297,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetOutputPort_56();
   public vtkAlgorithmOutput GetOutputPort() {
@@ -305,7 +305,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native int GetNumberOfInputConnections_57(int id0);
   public int GetNumberOfInputConnections(int id0)
@@ -321,7 +321,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkAlgorithmOutput)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetInputAlgorithm_60(int id0,int id1);
   public vtkAlgorithm GetInputAlgorithm(int id0,int id1) {
@@ -329,7 +329,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkAlgorithm)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetInputAlgorithm_61();
   public vtkAlgorithm GetInputAlgorithm() {
@@ -337,7 +337,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkAlgorithm)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetInputExecutive_62(int id0,int id1);
   public vtkExecutive GetInputExecutive(int id0,int id1) {
@@ -345,7 +345,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkExecutive)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetInputExecutive_63();
   public vtkExecutive GetInputExecutive() {
@@ -353,7 +353,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkExecutive)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetInputInformation_64(int id0,int id1);
   public vtkInformation GetInputInformation(int id0,int id1) {
@@ -361,7 +361,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetInputInformation_65();
   public vtkInformation GetInputInformation() {
@@ -369,7 +369,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native long GetOutputInformation_66(int id0);
   public vtkInformation GetOutputInformation(int id0) {
@@ -377,7 +377,7 @@ public class vtkAlgorithm extends vtkObject
 
     if (temp == 0) return null;
     return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   private native void Update_67(int id0);
   public void Update(int id0)
@@ -387,125 +387,145 @@ public class vtkAlgorithm extends vtkObject
   public void Update()
     { Update_68(); }
 
-  private native void UpdateInformation_69();
+  private native int Update_69(int id0,vtkInformationVector id1);
+  public int Update(int id0,vtkInformationVector id1)
+    { return Update_69(id0,id1); }
+
+  private native int Update_70(vtkInformation id0);
+  public int Update(vtkInformation id0)
+    { return Update_70(id0); }
+
+  private native int UpdatePiece_71(int id0,int id1,int id2,int id3[]);
+  public int UpdatePiece(int id0,int id1,int id2,int id3[])
+    { return UpdatePiece_71(id0,id1,id2,id3); }
+
+  private native int UpdateExtent_72(int id0[]);
+  public int UpdateExtent(int id0[])
+    { return UpdateExtent_72(id0); }
+
+  private native int UpdateTimeStep_73(double id0,int id1,int id2,int id3,int id4[]);
+  public int UpdateTimeStep(double id0,int id1,int id2,int id3,int id4[])
+    { return UpdateTimeStep_73(id0,id1,id2,id3,id4); }
+
+  private native void UpdateInformation_74();
   public void UpdateInformation()
-    { UpdateInformation_69(); }
+    { UpdateInformation_74(); }
 
-  private native void UpdateDataObject_70();
+  private native void UpdateDataObject_75();
   public void UpdateDataObject()
-    { UpdateDataObject_70(); }
+    { UpdateDataObject_75(); }
 
-  private native void PropagateUpdateExtent_71();
+  private native void PropagateUpdateExtent_76();
   public void PropagateUpdateExtent()
-    { PropagateUpdateExtent_71(); }
+    { PropagateUpdateExtent_76(); }
 
-  private native void UpdateWholeExtent_72();
+  private native void UpdateWholeExtent_77();
   public void UpdateWholeExtent()
-    { UpdateWholeExtent_72(); }
+    { UpdateWholeExtent_77(); }
 
-  private native void SetReleaseDataFlag_73(int id0);
+  private native void SetReleaseDataFlag_78(int id0);
   public void SetReleaseDataFlag(int id0)
-    { SetReleaseDataFlag_73(id0); }
+    { SetReleaseDataFlag_78(id0); }
 
-  private native int GetReleaseDataFlag_74();
+  private native int GetReleaseDataFlag_79();
   public int GetReleaseDataFlag()
-    { return GetReleaseDataFlag_74(); }
+    { return GetReleaseDataFlag_79(); }
 
-  private native void ReleaseDataFlagOn_75();
+  private native void ReleaseDataFlagOn_80();
   public void ReleaseDataFlagOn()
-    { ReleaseDataFlagOn_75(); }
+    { ReleaseDataFlagOn_80(); }
 
-  private native void ReleaseDataFlagOff_76();
+  private native void ReleaseDataFlagOff_81();
   public void ReleaseDataFlagOff()
-    { ReleaseDataFlagOff_76(); }
+    { ReleaseDataFlagOff_81(); }
 
-  private native int UpdateExtentIsEmpty_77(vtkInformation id0,vtkDataObject id1);
+  private native int UpdateExtentIsEmpty_82(vtkInformation id0,vtkDataObject id1);
   public int UpdateExtentIsEmpty(vtkInformation id0,vtkDataObject id1)
-    { return UpdateExtentIsEmpty_77(id0,id1); }
+    { return UpdateExtentIsEmpty_82(id0,id1); }
 
-  private native int UpdateExtentIsEmpty_78(vtkInformation id0,int id1);
+  private native int UpdateExtentIsEmpty_83(vtkInformation id0,int id1);
   public int UpdateExtentIsEmpty(vtkInformation id0,int id1)
-    { return UpdateExtentIsEmpty_78(id0,id1); }
+    { return UpdateExtentIsEmpty_83(id0,id1); }
 
-  private native void SetDefaultExecutivePrototype_79(vtkExecutive id0);
+  private native void SetDefaultExecutivePrototype_84(vtkExecutive id0);
   public void SetDefaultExecutivePrototype(vtkExecutive id0)
-    { SetDefaultExecutivePrototype_79(id0); }
+    { SetDefaultExecutivePrototype_84(id0); }
 
-  private native int SetUpdateExtentToWholeExtent_80(int id0);
+  private native int SetUpdateExtentToWholeExtent_85(int id0);
   public int SetUpdateExtentToWholeExtent(int id0)
-    { return SetUpdateExtentToWholeExtent_80(id0); }
+    { return SetUpdateExtentToWholeExtent_85(id0); }
 
-  private native int SetUpdateExtentToWholeExtent_81();
+  private native int SetUpdateExtentToWholeExtent_86();
   public int SetUpdateExtentToWholeExtent()
-    { return SetUpdateExtentToWholeExtent_81(); }
+    { return SetUpdateExtentToWholeExtent_86(); }
 
-  private native void SetUpdateExtent_82(int id0,int id1,int id2,int id3);
+  private native void SetUpdateExtent_87(int id0,int id1,int id2,int id3);
   public void SetUpdateExtent(int id0,int id1,int id2,int id3)
-    { SetUpdateExtent_82(id0,id1,id2,id3); }
+    { SetUpdateExtent_87(id0,id1,id2,id3); }
 
-  private native void SetUpdateExtent_83(int id0,int id1,int id2);
+  private native void SetUpdateExtent_88(int id0,int id1,int id2);
   public void SetUpdateExtent(int id0,int id1,int id2)
-    { SetUpdateExtent_83(id0,id1,id2); }
+    { SetUpdateExtent_88(id0,id1,id2); }
 
-  private native void SetUpdateExtent_84(int id0,int id1[]);
+  private native void SetUpdateExtent_89(int id0,int id1[]);
   public void SetUpdateExtent(int id0,int id1[])
-    { SetUpdateExtent_84(id0,id1); }
+    { SetUpdateExtent_89(id0,id1); }
 
-  private native void SetUpdateExtent_85(int id0[]);
+  private native void SetUpdateExtent_90(int id0[]);
   public void SetUpdateExtent(int id0[])
-    { SetUpdateExtent_85(id0); }
+    { SetUpdateExtent_90(id0); }
 
-  private native int[]  GetUpdateExtent_86();
+  private native int[]  GetUpdateExtent_91();
   public int[]  GetUpdateExtent()
-    { return GetUpdateExtent_86(); }
+    { return GetUpdateExtent_91(); }
 
-  private native int[]  GetUpdateExtent_87(int id0);
+  private native int[]  GetUpdateExtent_92(int id0);
   public int[]  GetUpdateExtent(int id0)
-    { return GetUpdateExtent_87(id0); }
+    { return GetUpdateExtent_92(id0); }
 
-  private native void GetUpdateExtent_88(int id0[]);
+  private native void GetUpdateExtent_93(int id0[]);
   public void GetUpdateExtent(int id0[])
-    { GetUpdateExtent_88(id0); }
+    { GetUpdateExtent_93(id0); }
 
-  private native void GetUpdateExtent_89(int id0,int id1[]);
+  private native void GetUpdateExtent_94(int id0,int id1[]);
   public void GetUpdateExtent(int id0,int id1[])
-    { GetUpdateExtent_89(id0,id1); }
+    { GetUpdateExtent_94(id0,id1); }
 
-  private native int GetUpdatePiece_90();
+  private native int GetUpdatePiece_95();
   public int GetUpdatePiece()
-    { return GetUpdatePiece_90(); }
+    { return GetUpdatePiece_95(); }
 
-  private native int GetUpdatePiece_91(int id0);
+  private native int GetUpdatePiece_96(int id0);
   public int GetUpdatePiece(int id0)
-    { return GetUpdatePiece_91(id0); }
+    { return GetUpdatePiece_96(id0); }
 
-  private native int GetUpdateNumberOfPieces_92();
+  private native int GetUpdateNumberOfPieces_97();
   public int GetUpdateNumberOfPieces()
-    { return GetUpdateNumberOfPieces_92(); }
+    { return GetUpdateNumberOfPieces_97(); }
 
-  private native int GetUpdateNumberOfPieces_93(int id0);
+  private native int GetUpdateNumberOfPieces_98(int id0);
   public int GetUpdateNumberOfPieces(int id0)
-    { return GetUpdateNumberOfPieces_93(id0); }
+    { return GetUpdateNumberOfPieces_98(id0); }
 
-  private native int GetUpdateGhostLevel_94();
+  private native int GetUpdateGhostLevel_99();
   public int GetUpdateGhostLevel()
-    { return GetUpdateGhostLevel_94(); }
+    { return GetUpdateGhostLevel_99(); }
 
-  private native int GetUpdateGhostLevel_95(int id0);
+  private native int GetUpdateGhostLevel_100(int id0);
   public int GetUpdateGhostLevel(int id0)
-    { return GetUpdateGhostLevel_95(id0); }
+    { return GetUpdateGhostLevel_100(id0); }
 
-  private native void SetProgressObserver_96(vtkProgressObserver id0);
+  private native void SetProgressObserver_101(vtkProgressObserver id0);
   public void SetProgressObserver(vtkProgressObserver id0)
-    { SetProgressObserver_96(id0); }
+    { SetProgressObserver_101(id0); }
 
-  private native long GetProgressObserver_97();
+  private native long GetProgressObserver_102();
   public vtkProgressObserver GetProgressObserver() {
-    long temp = GetProgressObserver_97();
+    long temp = GetProgressObserver_102();
 
     if (temp == 0) return null;
     return (vtkProgressObserver)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
-  }
+}
 
   public vtkAlgorithm() { super(); }
 
